@@ -36,8 +36,11 @@ def get_option_parser():
     cases.add_option('--dataset', dest='dataset', default=False, action='store_true', help='dataset tests')
     cases.add_option('--db-url', dest='db_url', default=False, action='store_true', help='db url tests')
     cases.add_option('--djpeewee', dest='djpeewee', default=False, action='store_true', help='djpeewee tests')
+    cases.add_option('--flask', dest='flask', default=False, action='store_true', help='flask utils tests')
     cases.add_option('--gfk', dest='gfk', default=False, action='store_true', help='gfk tests')
+    cases.add_option('--hybrid', dest='hybrid', default=False, action='store_true', help='hybrid property/method tests')
     cases.add_option('--kv', dest='kv', default=False, action='store_true', help='key/value store tests')
+    cases.add_option('--manytomany', dest='manytomany', default=False, action='store_true', help='manytomany field tests')
     cases.add_option('--migrations', dest='migrations', default=False, action='store_true', help='migration helper tests (requires psycopg2)')
     cases.add_option('--pool', dest='pool', default=False, action='store_true', help='connection pool tests')
     cases.add_option('--postgres-ext', dest='postgres_ext', default=False, action='store_true', help='postgres_ext tests (requires psycopg2)')
@@ -82,12 +85,26 @@ def collect_modules(options):
     if xtra(options.djpeewee):
         from playhouse.tests import test_djpeewee
         modules.append(test_djpeewee)
+    if xtra(options.flask):
+        try:
+            import flask
+        except ImportError:
+            print_('Unable to import Flask tests, Flask is not installed.')
+        else:
+            from playhouse.tests import test_flask_utils
+            modules.append(test_flask_utils)
     if xtra(options.gfk):
         from playhouse.tests import test_gfk
         modules.append(test_gfk)
+    if xtra(options.hybrid):
+        from playhouse.tests import test_hybrid
+        modules.append(test_hybrid)
     if xtra(options.kv):
         from playhouse.tests import test_kv
         modules.append(test_kv)
+    if xtra(options.manytomany):
+        from playhouse.tests import test_manytomany
+        modules.append(test_manytomany)
     if xtra(options.migrations):
         try:
             from playhouse.tests import test_migrate
@@ -119,8 +136,11 @@ def collect_modules(options):
         from playhouse.tests import test_signals
         modules.append(test_signals)
     if xtra(options.shortcuts):
+        from playhouse.tests import test_manytomany
         from playhouse.tests import test_shortcuts
         modules.append(test_shortcuts)
+        if test_manytomany not in modules:
+            modules.append(test_manytomany)
     if xtra(options.sqlcipher):
         try:
             from playhouse.tests import test_sqlcipher_ext
@@ -159,6 +179,7 @@ if __name__ == '__main__':
 
     files_to_delete = [
         'peewee_test.db',
+        'peewee_test',
         'tmp.db',
         'peewee_test.bdb.db',
         'peewee_test.cipher.db']
