@@ -1,6 +1,11 @@
+"""
+Aggregate all the test modules and run from the command-line. For information
+about running tests, see the README located in the `playhouse/tests` directory.
+"""
 import sys
 import unittest
 
+from playhouse.tests.test_apis import *
 from playhouse.tests.test_compound_queries import *
 from playhouse.tests.test_database import *
 from playhouse.tests.test_fields import *
